@@ -2,7 +2,9 @@ setMethod(f = "getmultiKmax",signature = "CGHdata",
           definition = function(.Object,CGHo,uniKmax=NULL,multiKmax=NULL){
             
             M       = length(names(.Object@Y))
-            uniKmax = getuniKmax(.Object,CGHo,uniKmax)
+            if (is.null(uniKmax)){
+              uniKmax = getuniKmax(.Object,CGHo,uniKmax)
+            }
             
             if (is.null(multiKmax)){
               if (CGHo["select"] == "none"){
@@ -10,7 +12,7 @@ setMethod(f = "getmultiKmax",signature = "CGHdata",
                 cat("[check getmultiKmax] multiKmax is initialized by default\n")
                 cat("**********************************************************\n")
               }
-              multiKmax    = floor(sum(unlist(uniKmax)) * CGHo["beta"])
+              multiKmax    = floor(sum(unlist(uniKmax))) * CGHo["beta"]
             } else {
               if (multiKmax < M){
                 cat("[getmultiKmax]  multiKmax should be greater that the number of patients (",M,") \n")
