@@ -4,26 +4,32 @@ unisegmean <- function(Y,CGHo,Kmax){
   present.data = which(!is.na(Y))
   missing.data = which(is.na(Y))
   x            = Y[present.data]
-  #lmax         = floor(CGHo["lmax"]*length(x))    
-  #out         = segmean(x,Kmax,CGHo["lmin"],lmax,vh = TRUE)  
-  #out          = segmeanGR(x,Kmax)
-   out          = segmeanCO(x,Kmax)
+  out          = segmeanCO(x,Kmax)
   loglik       = -(length(x)/2)*(log(2*pi*out$J.est/(length(x)))+1)
-  #t.est        = bpwmissing(out$t.est,present.data,n.com)
   
   if (CGHo["select"]=="none"){
     Kselect = Kmax
   } else {    
-    Kseq    = c(1:Kmax)
-    Kselect = Kselection(x,out$t.est,out$J.est,Kseq,CGHo)
+    mBIC = sapply(1:Kmax,FUN=function(K){
+      th      = out$t.est[K,1:K]
+      rupt    = matrix(ncol=2,c(c(1,th[1:K-1]+1),th))
+	  resmean = meanRuptR_c(Y, rupt[,2], K)
+      mu      = data.frame(begin = rupt[,1],
+        end   = rupt[,2],
+        mean  = resmean)    
+      mu      = list(aux=mu)  
+      getmBIC(K,loglik[K],mu,CGHo)   
+	})
+    Kselect = which.max(mBIC)
   }
   
-  t.est        = bpwmissing(out$t.est,present.data,n.com)
+  t.est   = bpwmissing(out$t.est,present.data,n.com)
   th      = t.est[Kselect,1:Kselect]
-  rupt    = matrix(ncol=2,c(c(1,th[1:Kselect-1]+1),th))    
+  rupt    = matrix(ncol=2,c(c(1,th[1:Kselect-1]+1),th)) 
+  resmean = meanRuptR_c(Y, rupt[,2], Kselect)
   mu      = data.frame(begin = rupt[,1],
     end   = rupt[,2],
-    mean  = apply(rupt,1,FUN=function(z) mean(Y[z[1]:z[2]], na.rm=T)))    
+    mean  = resmean)     
   invisible(list(mu=mu,loglik=loglik,t.est=t.est))
   
 }
@@ -39,3 +45,5 @@ bpwmissing <- function(t.est,present.data,n.com){
   diag(t.est) = n.com
   invisible(t.est)
 }
+
+
